/*  Copyright 1996,1997,1999,2001,2002,2008,2009 Alain Knaff.
 *  This file is part of mtools.
 *
 *  Mtools is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Mtools is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Mtools.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#if __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6) || defined(__clang__)
# define HAVE_PRAGMA_DIAGNOSTIC 1
#endif

#if defined HAVE_PRAGMA_DIAGNOSTIC && defined __clang__
# pragma clang diagnostic push
# pragma clang diagnostic ignored "-Wreserved-macro-identifier"
#endif

#include "config.h"

#if defined HAVE_PRAGMA_DIAGNOSTIC && defined __clang__
# pragma clang diagnostic pop
#endif


#ifndef HAVE_ICONV_H

#include "codepage.h"

Codepage_t codepages[]= {
	{ 437,
	  ""
	  "ܢPf"
	  "Ѫr"
	  "_______________"
	  "________________"
	  "________________"
	  "abgpSstftod_N"
	  "=<>||~Vn__"
	},

	{ 819,
	  "________________"
	  "________________"
	  ""
	  ""
	  ""
	  ""
	  ""
	  ""
	},

	{ 850,
	  ""
	  "_"
	  "Ѫ"
	  "_________"
	  "_____________"
	  "i____|I_"
	  "յޯ"
	  "___"
	},

	{ 852,
	  "uclZC"
	  "LlLlSsTtLc"
	  "AaZzEe zCs"
	  "_____ES____Zz"
	  "______Aa_______"
	  "Dde_r__TU_"
	  "NnSsRrUt"
	  "~.~~uRr_"
	},

	{ 860,
	  ""
	  "ܢP"
	  "ѪҬ"
	  "_______________"
	  "________________"
	  "________________"
	  "abgpSstftod_N"
	  "=<>||~Vn__"
	},

	{ 863,
	  "_"
	  "ܢf"
	  "| r"
	  "_______________"
	  "________________"
	  "________________"
	  "abgpSstftod_N"
	  "=<>||~Vn__"
	},

	{ 865,
	  ""
	  "Pf"
	  "Ѫr"
	  "_______________"
	  "________________"
	  "________________"
	  "abgpSstftod_N"
	  "=<>||~Vn__",
	},

	/* Taiwanese (Chinese Complex Character) support */
	{ 950,
	 ""
	 ""
	 ""
	 ""
	 ""
	 ""
	 ""
	 "",
	},


	{ 0 }
};
#else
/* Shut up warning: ISO C forbids an empty translation unit warning [-Wpedantic]: */
typedef int make_iso_compilers_happy;
#endif
